pub struct CreateRequest {
pub payer: String,
pub new_account: String,
pub owner: String,
pub lamports: u64,
pub space: u64,
}Expand description
CreateRequest represents the parameters needed to create a new Solana account Maps to the Solana system program’s create_account instruction
Fields
payer: StringThe account that will pay for the new account creation (must be a signer)
new_account: StringThe public key of the new account to be created (must be a signer)
owner: StringThe program that will own the new account (defaults to system program)
lamports: u64Amount of lamports to transfer to the new account
space: u64Number of bytes of memory to allocate for the account