pub struct CreateWithSeedRequest {
pub payer: String,
pub new_account: String,
pub base: String,
pub seed: String,
pub lamports: u64,
pub space: u64,
}Expand description
CreateWithSeedRequest creates a new account with a seed
Fields
payer: StringThe account that will pay for the new account creation (must be a signer)
new_account: StringThe public key of the new account to be created
base: StringThe base public key used to derive the new account address
seed: StringThe seed string used to derive the new account address
lamports: u64Amount of lamports to transfer to the new account
space: u64Number of bytes of memory to allocate for the account