pub struct CreateMintRequest {
pub payer: String,
pub mint_pub_key: String,
pub mint_authority_pub_key: String,
pub freeze_authority_pub_key: String,
pub decimals: u32,
pub token_program: i32,
}Expand description
Request to create and initialize a mint account in one call
Fields
payer: StringSystem program create fields
Account paying for creation (signer)
mint_pub_key: StringToken program initialize mint fields
Same as new_account for validation
Mint authority
Freeze authority (optional)
decimals: u32Mint decimals
token_program: i32Implementations
Sourceimpl CreateMintRequest
impl CreateMintRequest
Sourcepub fn token_program(&self) -> TokenProgram
pub fn token_program(&self) -> TokenProgram
Returns the enum value of token_program, or the default if the field is set to an invalid enum value.
Sourcepub fn set_token_program(&mut self, value: TokenProgram)
pub fn set_token_program(&mut self, value: TokenProgram)
Sets token_program to the provided enum value.